@@ -3,6 +3,7 @@ from __future__ import (absolute_import, division, print_function,
 
 import collections
 from datetime import datetime, timedelta
+from dateutil.parser import parse as date_parse
 import time as _time
 import threading
 import asyncio
@@ -324,7 +325,8 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
         :param dtbegin: datetime start
         :param dtend: datetime end
         :param timeframe: bt.TimeFrame
-        :param compression: distance between samples. e.g if 1 => get sample every day. if 3 => get sample every 3 days
+        :param compression: distance between samples. e.g if 1 =>
+                 get sample every day. if 3 => get sample every 3 days
         :param candleFormat: (bidask, midpoint, trades)
         :param includeFirst:
         :return:
@@ -338,6 +340,16 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
         t.start()
         return q
 
+    @staticmethod
+    def iso_date(date_str):
+        """
+        this method will make sure that dates are formatted properly
+        as with isoformat
+        :param date_str:
+        :return: YYYY-MM-DD date formatted
+        """
+        return date_parse(date_str).date().isoformat()
+
     def _t_candles(self, dataname, dtbegin, dtend, timeframe, compression,
                    candleFormat, includeFirst, q):
 
@@ -367,11 +379,13 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
                 start_dt = None
                 if dtkwargs['start']:
                     start_dt = dtkwargs['start'].isoformat()
-                response = self.oapi.polygon.historic_agg_v2(dataname,
-                                                             compression,
-                                                             granularity,
-                                                             _from=start_dt,
-                                                             to=end_dt)
+                response = \
+                    self.oapi.polygon.historic_agg_v2(
+                        dataname,
+                        compression,
+                        granularity,
+                        _from=self.iso_date(start_dt),
+                        to=self.iso_date(end_dt))
             except AlpacaError as e:
                 print(str(e))
                 q.put(e.error_response)
@@ -406,7 +420,10 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
                                       'low': 'min',
                                       'close': 'last',
                                       'volume': 'sum'})
-        cdl = cdl.loc[dtbegin.replace(tzinfo=pytz.timezone(NY)):dtend.replace(tzinfo=pytz.timezone(NY))].dropna(subset=['high'])
+        cdl = cdl.loc[
+              dtbegin.replace(tzinfo=pytz.timezone(NY)):
+              dtend.replace(tzinfo=pytz.timezone(NY))
+              ].dropna(subset=['high'])
         records = cdl.reset_index().to_dict('records')
         for r in records:
             r['time'] = r['timestamp']
